HeifDecoder class final

Decodes primary HEIF/HEIC images, including grids, alpha and orientation.

Inheritance

Constructors

HeifDecoder()
Creates a bounded HEIF decoder.
const

Properties

defaultDecodeOptions → HeifDecodeOptions
The default decode options.
finalinherited
format → NativeImageFormat
Container format accepted by this decoder.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Uint8List> stream) → Stream<Image>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Uint8List input, {HeifDecodeOptions? decodeOptions}) → Image
Converts input and returns the result of the conversion.
inherited
decode(Uint8List input, {HeifDecodeOptions? decodeOptions}) → Image
Decodes input to an image.
inherited
decodeAsync(Uint8List input, {HeifDecodeOptions? decodeOptions}) → Future<Image>
Decodes on a native isolate or browser Worker.
inherited
decodeData(Uint8List input, {HeifDecodeOptions? decodeOptions, int? maxDecodedBytes, int? maxIccProfileBytes}) → DecodedImage
Decodes normalized uint16 RGBA for high-bit-depth input, otherwise RGBA8.
inherited
decodeDataAsync(Uint8List input, {HeifDecodeOptions? decodeOptions, int? maxDecodedBytes, int? maxIccProfileBytes}) → Future<DecodedImage>
Preserves high-precision samples on a native isolate or browser Worker.
inherited
decodeWithOptions(Uint8List input, HeifDecodeOptions options) → Image
Decodes input to an image, with the given options or default options.
inherited
fuse<TT>(Converter<Image, TT> other) → Converter<Uint8List, TT>
Fuses this with other.
inherited
inspect(Uint8List input, {int maxIccProfileBytes = defaultMaxIccProfileBytes, int maxMetadataBytes = defaultMaxDescriptiveMetadataBytes}) → DecodedImageMetadata
Reads dimensions, depth and bounded ICC, EXIF and XMP payloads.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Image> sink) → Sink<Uint8List>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited