NativeQoiEncoder class final

Encodes QOI through the reference QOI library using Imcodec's options.

Inheritance

Constructors

NativeQoiEncoder({int maxOutputBytes = defaultMaxEncodedBytes})
Creates a native QOI encoder with a bounded output allocation.
const

Properties

defaultEncodeOptions → QoiEncodeOptions
The default encode options.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
maxOutputBytes → int
Maximum size of one encoded output buffer.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Image> stream) → Stream<Uint8List>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Image input, {QoiEncodeOptions? encodeOptions}) → Uint8List
Converts input and returns the result of the conversion.
inherited
createRequest(Image image, QoiEncodeOptions options) → NativeRequest
Describes one encoding operation without retaining native pointers.
encode(Image input, {QoiEncodeOptions? encodeOptions}) → Uint8List
Encodes input to raster bytes.
inherited
encodeImageWith(ParallelRunner runner, Image input, QoiEncodeOptions options) → Future<Uint8List>
Encodes input, offering runner the parts that can run independently.
inherited
encodeWith(ParallelRunner runner, Image input, {QoiEncodeOptions? encodeOptions}) → Future<Uint8List>
Encodes input, offering runner the parts that can run independently.
inherited
encodeWithOptions(Image input, QoiEncodeOptions options) → Uint8List
Encodes input to raster bytes, with the given options or default options.
inherited
finishEncoding(Uint8List encoded, QoiEncodeOptions options) → Uint8List
Adds what the engine cannot write to its encoded output.
inherited
fuse<TT>(Converter<Uint8List, TT> other) → Converter<Image, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Uint8List> sink) → Sink<Image>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited