Converts an Image to encoded raster bytes.
- Inheritance
- Implementers
Constructors
- RasterEncoder({required Options defaultEncodeOptions})
-
Creates a raster encoder.
const
Properties
- defaultEncodeOptions → Options
-
The default encode options.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< Image> stream) → Stream<Uint8List> -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
Image input, {Options? encodeOptions}) → Uint8List -
Converts
inputand returns the result of the conversion.override -
encode(
Image input, {Options? encodeOptions}) → Uint8List -
Encodes
inputto raster bytes. -
encodeWithOptions(
Image input, Options encodeOptions) → Uint8List -
Encodes
inputto raster bytes, with the given options or default options. -
fuse<
TT> (Converter< Uint8List, TT> other) → Converter<Image, TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink< Uint8List> sink) → Sink<Image> -
Starts a chunked conversion.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited