NativeQoiEncoder class final
Encodes QOI through the reference QOI library using Imcodec's options.
- Inheritance
-
- Object
- Converter<
Image, Uint8List> - RasterEncoder<
QoiEncodeOptions> - NativeQoiEncoder
Constructors
- NativeQoiEncoder({int maxOutputBytes = defaultMaxEncodedBytes})
-
Creates a native QOI encoder with a bounded output allocation.
const
Properties
- defaultEncodeOptions → QoiEncodeOptions
-
The default encode options.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxOutputBytes → int
-
Maximum size of one encoded output buffer.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< Image> stream) → Stream<Uint8List> -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
Image input, {QoiEncodeOptions? encodeOptions}) → Uint8List -
Converts
inputand returns the result of the conversion.inherited -
createRequest(
Image image, QoiEncodeOptions options) → NativeRequest - Describes one encoding operation without retaining native pointers.
-
encode(
Image input, {QoiEncodeOptions? encodeOptions}) → Uint8List -
Encodes
inputto raster bytes.inherited -
encodeImageWith(
ParallelRunner runner, Image input, QoiEncodeOptions options) → Future< Uint8List> -
Encodes
input, offeringrunnerthe parts that can run independently.inherited -
encodeWith(
ParallelRunner runner, Image input, {QoiEncodeOptions? encodeOptions}) → Future< Uint8List> -
Encodes
input, offeringrunnerthe parts that can run independently.inherited -
encodeWithOptions(
Image input, QoiEncodeOptions options) → Uint8List -
Encodes
inputto raster bytes, with the given options or default options.inherited -
finishEncoding(
Uint8List encoded, QoiEncodeOptions options) → Uint8List -
Adds what the engine cannot write to its
encodedoutput.inherited -
fuse<
TT> (Converter< Uint8List, TT> other) → Converter<Image, TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink< Uint8List> sink) → Sink<Image> -
Starts a chunked conversion.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited