TiffEncodeOptions class final
Options for the TIFF encoder.
- Inheritance
-
- Object
- RasterEncodeOptions
- TiffEncodeOptions
Constructors
- TiffEncodeOptions({TiffCompression compression = TiffCompression.packBits, double? pixelsPerInch})
-
Creates a TIFF encode with the default options.
const
Properties
- compression → TiffCompression
-
Compression used when encoding pixel strips.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pixelsPerInch → double?
-
Optional square pixel density, defaulting to the legacy 72 DPI output.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited